@@ -8,9 +8,9 @@ import torch
 from ase import Atoms
 from ase.optimize import BFGS
 import ase.calculators.calculator
-from ase.lattice.cubic import Diamond
-from batch_opt.ANI2xt import ANI2xt
+from ..batch_opt.ANI2xt import ANI2xt
 import torchani
+from openbabel import pybel
 
 
 class EnForce_ANI(torch.nn.Module):
@@ -101,7 +101,8 @@ def opt_geometry(path: str, model_name:str, gpu_idx=0, opt_tol=0.003, opt_steps=
     model_name: ANI2xt or AIMNET
     gpu_idx: GPU cuda index
     opt_tol: Convergence_threshold for geometry optimization (eV/A)
-    opt_steps: Maximum geometry optimizaiton steps"""
+    opt_steps: Maximum geometry optimizaiton steps
+    """
     ev2hatree = 1/27.211385
     #create output path that is in the same directory as the input file
     dir = os.path.dirname(path)
