@@ -8,7 +8,7 @@ sys.path.append(root)
 import torch
 from ase import Atoms
 import ase.calculators.calculator
-from batch_opt.ANI2xt import ANI2xt
+from .batch_opt.ANI2xt import ANI2xt
 import torchani
 from openbabel import pybel
 from tqdm import tqdm
