@@ -14,12 +14,12 @@ import psutil, tarfile
 import glob
 import pandas as pd
 import multiprocessing as mp
-from isomer_engine import rd_isomer, tautomer_engine
-from isomer_engine import oe_isomer
-from ranking import ranking
-from utils import housekeeping, check_input
-from utils import hash_taut_smi,  my_name_space
-from batch_opt.batchopt import optimizing
+from .isomer_engine import rd_isomer, tautomer_engine
+from .isomer_engine import oe_isomer
+from .ranking import ranking
+from .utils import housekeeping, check_input
+from .utils import hash_taut_smi,  my_name_space
+from .batch_opt.batchopt import optimizing
 from send2trash import send2trash
 try:
     mp.set_start_method('spawn')
@@ -27,7 +27,6 @@ except:
     pass
 
 
-
 def create_chunk_meta_names(path, dir):
     """Output name is based on chunk input path and directory
     path: chunck input smi path
